@@ -82,49 +82,47 @@ test_that("test MOSEK SDP", {
   expect_equal(complementary_slackness, 0.0, tolerance = TOL)
 })
 
-# test_that("test MOSEK exponential cone", {a
-#   skip_on_cran()
-#   skip_if_not(MOSEK_AVAILABLE, "Skipping MOSEK test as it is not available.!")
-#   # Formulate the following exponential cone problem with cvxpy
-#   #   min   3 * x[1] + 2 * x[2] + x[3]
-#   #     s.t.  0.1 <= x[1] + x[2] + x[3] <= 1
-#   #           x >= 0
-#   #           x[1] >= x[2] * exp(x[3] / x[2])
-#   # and solve with MOSEK and ECOS. Ensure that MOSEK and ECOS have the same
-#   # primal and dual solutions.
-#   #
-#   # Note that the exponential cone constraint can be rewritten in terms of the
-#   # relative entropy cone. The correspondence is as follows:
-#   #     x[1] >= x[2] * exp(x[3] / x[2])
-#   #       iff
-#   #     x[2] * log(x[2] / x[1]) + x[3] <= 0.
-#
-#   if("MOSEK" %in% installed_solvers()) {
-#     # TODO: Only run if exponential cone is supported.
-#     # Formulate and solve the problem with CVXR
-#     x <- Variable(3, 1)
-#     constraints <- list(sum(x) <= 1.0, sum(x) >= 0.1, x >= 0.01,
-#                         kl_div(x[2], x[1]) + x[2] - x[1] + x[3] <= 0)
-#     obj <- Minimize(3 * x[1] + 2 * x[2] + x[1])
-#     prob <- Problem(obj, constraints)
-#     result_mosek <- solve(prob, solver = "MOSEK")
-#     val_mosek = result_mosek$value
-#     x_mosek = result_mosek$getValue(x)
-#     duals_mosek = lapply(constraints, function(c) { result_mosek$getDualValue(c) })
-#
-#     result_ecos <- solve(prob, solver = "ECOS")
-#     val_ecos = result_ecos$value
-#     x_ecos = result_ecos$getValue(x)
-#     duals_ecos = lapply(constraints, function(c) { result_ecos$getDualValue(c) })
-#
-#     # Verify results
-#     expect_equal(val_mosek, val_ecos, tolerance = TOL)
-#     expect_equal(x_mosek, x_ecos, tolerance = 1e-4)
-#     expect_equal(length(duals_ecos), length(duals_mosek))
-#     for(i in seq_along(duals_mosek))
-#       expect_equal(duals_mosek[[i]], duals_ecos[[i]], tolerance = 1e-4)
-#   }
-# })
+test_that("test MOSEK exponential cone", {
+  skip_on_cran()
+  skip_if_not(MOSEK_AVAILABLE, "Skipping MOSEK test as it is not available.!")
+  # Formulate the following exponential cone problem with cvxpy
+  #   min   3 * x[1] + 2 * x[2] + x[3]
+  #     s.t.  0.1 <= x[1] + x[2] + x[3] <= 1
+  #           x >= 0
+  #           x[1] >= x[2] * exp(x[3] / x[2])
+  # and solve with MOSEK and ECOS. Ensure that MOSEK and ECOS have the same
+  # primal and dual solutions.
+  #
+  # Note that the exponential cone constraint can be rewritten in terms of the
+  # relative entropy cone. The correspondence is as follows:
+  #     x[1] >= x[2] * exp(x[3] / x[2])
+  #       iff
+  #     x[2] * log(x[2] / x[1]) + x[3] <= 0.
+
+  ## TODO: Only run if exponential cone is supported.
+  ## Formulate and solve the problem with CVXR
+  x <- Variable(3, 1)
+  constraints <- list(sum(x) <= 1.0, sum(x) >= 0.1, x >= 0.01,
+                      kl_div(x[2], x[1]) + x[2] - x[1] + x[3] <= 0)
+  obj <- Minimize(3 * x[1] + 2 * x[2] + x[1])
+  prob <- Problem(obj, constraints)
+  result_mosek <- solve(prob, solver = "MOSEK")
+  val_mosek = result_mosek$value
+  x_mosek = result_mosek$getValue(x)
+  duals_mosek = lapply(constraints, function(c) { result_mosek$getDualValue(c) })
+
+  result_ecos <- solve(prob, solver = "ECOS")
+  val_ecos = result_ecos$value
+  x_ecos = result_ecos$getValue(x)
+  duals_ecos = lapply(constraints, function(c) { result_ecos$getDualValue(c) })
+
+  ## Verify results
+  expect_equal(val_mosek, val_ecos, tolerance = TOL)
+  expect_equal(x_mosek, x_ecos, tolerance = 1e-4)
+  expect_equal(length(duals_ecos), length(duals_mosek))
+  for(i in seq_along(duals_mosek))
+      expect_equal(duals_mosek[[i]], duals_ecos[[i]], tolerance = 1e-4)
+})
 
 test_that("test MOSEK MI SOCP", {
   skip_on_cran()
